@@ -472,6 +472,7 @@ anjuta_plugin_handle_new (const gchar *plugin_desc_path)
 	AnjutaPluginHandle *plugin_handle;
 	AnjutaPluginDescription *desc;
 	char *str;
+	gboolean *enable;
 	gchar *contents;
 	gboolean success = TRUE;
 	
@@ -542,18 +543,14 @@ anjuta_plugin_handle_new (const gchar *plugin_desc_path)
 		g_free (str);
 	}
 	
-	if (anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
-											  "UserActivatable", &str)) {
-		if (str && strcasecmp (str, "no") == 0)
-		{
-			plugin_handle->priv->user_activatable = FALSE;
-			/*
-			DEBUG_PRINT ("Plugin '%s' is not user activatable",
-						 plugin_handle->priv->name?
-						 plugin_handle->priv->name : "Unknown");
-			*/
-		}
-		g_free (str);
+	if (anjuta_plugin_description_get_boolean (desc, "Anjuta Plugin",
+											  "UserActivatable", &enable) && !enable) {
+		plugin_handle->priv->user_activatable = FALSE;
+		/*
+		DEBUG_PRINT ("Plugin '%s' is not user activatable",
+					 plugin_handle->priv->name?
+					 plugin_handle->priv->name : "Unknown");
+		*/
 	}
 	
 	if (anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
