@@ -49,10 +49,15 @@ struct _AnjutaDevhelp{
 #ifndef DISABLE_EMBEDDED_DEVHELP
 	DhBase         *base;
 #endif /* DISABLE_EMBEDDED_DEVHELP */
-	GtkWidget     *htmlview;    
+	GtkWidget      *view;
+	GtkWidget      *view_sw;
 	GtkWidget      *control_notebook; 
+	GtkWidget      *main_vbox;
 	GtkWidget      *book_tree;
 	GtkWidget      *search;
+	GtkWidget      *go_back;
+	GtkWidget      *go_forward;
+	GtkWidget      *online;
 	
 	IAnjutaEditor	*editor;
 	guint editor_watch_id;
