@@ -51,7 +51,8 @@ enum
 	PROP_BASE_URI,
 	PROP_FILTER_BINARY,
 	PROP_FILTER_HIDDEN,
-	PROP_FILTER_BACKUP
+	PROP_FILTER_BACKUP,
+	PROP_FILTER_UNVERSIONED
 };
 
 typedef struct _FileModelPrivate FileModelPrivate;
@@ -63,6 +64,7 @@ struct _FileModelPrivate
 	gboolean filter_binary;
 	gboolean filter_hidden;
 	gboolean filter_backup;
+	gboolean filter_unversioned;
 	
 	GtkTreeView* view;
 };
@@ -131,7 +133,7 @@ typedef struct
 #define EMBLEM_IGNORED "vcs-ignored.png"
 #define EMBLEM_LOCKED "vcs-locked.png"
 #define EMBLEM_UNVERSIONED "vcs-unversioned.png"
-#define EMBLEM_UPDATED "vcs-updated.png"
+#define EMBLEM_UPTODATE "vcs-updated.png"
 #define EMBLEM_MODIFIED "vcs-modified.png"
 
 #define COMPOSITE_ALPHA 225
@@ -142,9 +144,6 @@ get_vcs_emblem (AnjutaVcsStatus status)
 	GdkPixbuf* emblem ;
 	switch (status)
 	{
-		case ANJUTA_VCS_STATUS_NONE:
-			emblem = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"EMBLEM_UPDATED, NULL);
-			break;
 		case ANJUTA_VCS_STATUS_ADDED:
 			emblem = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"EMBLEM_ADDED, NULL);
 			break;
@@ -163,6 +162,12 @@ get_vcs_emblem (AnjutaVcsStatus status)
 		case ANJUTA_VCS_STATUS_UNVERSIONED:
 			emblem = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"EMBLEM_UNVERSIONED, NULL);
 			break;
+		case ANJUTA_VCS_STATUS_UPTODATE:
+			emblem = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"EMBLEM_UPTODATE, NULL);
+			break;
+		case ANJUTA_VCS_STATUS_IGNORED:
+			emblem = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"EMBLEM_IGNORED, NULL);
+			break;
 		default:
 			emblem = NULL;
 	}
@@ -176,10 +181,9 @@ file_model_vcs_status_callback(GFile *file,
 							   gpointer user_data)
 {
 	VcsData* data = user_data;
+	FileModelPrivate *priv = FILE_MODEL_GET_PRIVATE (data->model);
 	gchar* path = g_file_get_path (file);
-	
-	DEBUG_PRINT ("Status of %s = %d", path, status);
-	
+		
 	GtkTreePath* tree_path = gtk_tree_row_reference_get_path (data->ref);
 	if (tree_path)
 	{
@@ -192,41 +196,49 @@ file_model_vcs_status_callback(GFile *file,
 								 &iter,
 								 tree_path);
 		
-		emblem = get_vcs_emblem (status);
-		if (emblem)
+		if (priv->filter_unversioned &&
+			(status == ANJUTA_VCS_STATUS_UNVERSIONED ||
+			 status == ANJUTA_VCS_STATUS_IGNORED))
 		{
-			gtk_tree_model_get (model, &iter,
-								COLUMN_PIXBUF, &file_icon,
-								-1);
-			if (file_icon)
+			gtk_tree_store_remove (GTK_TREE_STORE (model), &iter);
+		}
+		else
+		{
+			emblem = get_vcs_emblem (status);
+			if (emblem)
 			{
-				gdk_pixbuf_composite (emblem,
-									  file_icon,
-									  0, 0,
-									  gdk_pixbuf_get_width (file_icon),
-									  gdk_pixbuf_get_height (file_icon),
-									  0, 0,
-									  1, 1,
-									  GDK_INTERP_BILINEAR,
-									  COMPOSITE_ALPHA);
-				gtk_tree_store_set (GTK_TREE_STORE (model),
-									&iter,
-									COLUMN_PIXBUF,
-									file_icon,
+				gtk_tree_model_get (model, &iter,
+									COLUMN_PIXBUF, &file_icon,
 									-1);
-				DEBUG_PRINT ("%s", "setting emblem");
-				
-				g_object_unref (file_icon);
+				if (file_icon)
+				{
+					gdk_pixbuf_composite (emblem,
+										  file_icon,
+										  0, 0,
+										  gdk_pixbuf_get_width (file_icon),
+										  gdk_pixbuf_get_height (file_icon),
+										  0, 0,
+										  1, 1,
+										  GDK_INTERP_BILINEAR,
+										  COMPOSITE_ALPHA);
+					gtk_tree_store_set (GTK_TREE_STORE (model),
+										&iter,
+										COLUMN_PIXBUF,
+										file_icon,
+										-1);
+					DEBUG_PRINT ("%s", "setting emblem");
+					
+					g_object_unref (file_icon);
+				}
+				g_object_unref (emblem);
 			}
-			g_object_unref (emblem);
+			
+			gtk_tree_store_set (GTK_TREE_STORE (model),
+								&iter,
+								COLUMN_STATUS,
+								status,
+								-1);
 		}
-		
-
-		gtk_tree_store_set (GTK_TREE_STORE (model),
-							&iter,
-							COLUMN_STATUS,
-							status,
-							-1);
 		gtk_tree_path_free (tree_path);
 	}
 	g_free(path);
@@ -616,6 +628,9 @@ file_model_set_property (GObject *object, guint prop_id, const GValue *value, GP
 	case PROP_FILTER_BACKUP:
 		priv->filter_backup = g_value_get_boolean (value);
 		break;
+	case PROP_FILTER_UNVERSIONED:
+		priv->filter_unversioned = g_value_get_boolean (value);
+		break;
 
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -640,7 +655,9 @@ file_model_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
 	case PROP_FILTER_HIDDEN:
 		g_value_set_boolean (value, priv->filter_hidden);
 	case PROP_FILTER_BACKUP:
-		g_value_set_boolean (value, priv->filter_backup);	
+		g_value_set_boolean (value, priv->filter_backup);
+	case PROP_FILTER_UNVERSIONED:
+		g_value_set_boolean (value, priv->filter_unversioned);
 		
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -691,6 +708,14 @@ file_model_class_init (FileModelClass *klass)
 														   TRUE,
 														   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	
+	g_object_class_install_property (object_class,
+									 PROP_FILTER_UNVERSIONED,
+									 g_param_spec_boolean ("filter_unversioned",
+														   "Filter unversioned files",
+														   "file_unversioned",
+														   TRUE,
+														   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	
 }
 
 FileModel*
