@@ -530,7 +530,7 @@ cpp_java_assist_create_word_completion_cache (CppJavaAssist *assist)
 										   IANJUTA_SYMBOL_TYPE_MAX,
 										   TRUE,
 										   IANJUTA_SYMBOL_FIELD_SIMPLE|IANJUTA_SYMBOL_FIELD_TYPE,
-										   assist->priv->pre_word, TRUE, FALSE, FALSE, -1, -1, NULL);
+										   assist->priv->pre_word, TRUE, TRUE, FALSE, -1, -1, NULL);
 		
 		IAnjutaIterable* iter_globals = 
 			ianjuta_symbol_manager_search (assist->priv->isymbol_manager,
@@ -883,7 +883,7 @@ on_assist_chosen (IAnjutaEditorAssist* iassist, gint selection,
 	{
 		ianjuta_iterable_next (iter, NULL);
 		ianjuta_editor_selection_set (IANJUTA_EDITOR_SELECTION (te),
-									  iter, cur_pos, NULL);
+									  iter, cur_pos, FALSE, NULL);
 		ianjuta_editor_selection_replace (IANJUTA_EDITOR_SELECTION (te),
 										  assistance->str, -1, NULL);
 		g_free (pre_word);
