@@ -80,20 +80,20 @@ sdb_engine_iterator_class_init (SymbolDBEngineIteratorClass *klass)
 
 SymbolDBEngineIterator *
 symbol_db_engine_iterator_new (GdaDataModel *model, 
-							   const GHashTable *sym_type_conversion_hash)
+							   const GHashTable *sym_type_conversion_hash,
+							   const gchar *prj_directory)
 {
 	SymbolDBEngineIterator *dbi;
 	SymbolDBEngineIteratorPriv *priv;
 	
 	g_return_val_if_fail (model != NULL, NULL);
-	
+
 	dbi = g_object_new (SYMBOL_TYPE_DB_ENGINE_ITERATOR, NULL);
-	
 	priv = dbi->priv;
 	
 	priv->data_model = model;
-	priv->data_iter = gda_data_model_create_iter (model);
-	
+	priv->data_iter = gda_data_model_create_iter (model);	
+
 	/* because gda_data_model_get_n_rows () could be cpu-intensive, we'll 
 	 * proxy this value, e.g. it's calculated if it is really needed */
 	priv->total_rows = -1; 
@@ -101,17 +101,20 @@ symbol_db_engine_iterator_new (GdaDataModel *model,
 	/* to avoid calling everytime this function when we want to use the IteratorNode,
 	 * just do it now.
 	 */
-	symbol_db_engine_iterator_first (dbi);
-	
+	if (symbol_db_engine_iterator_first (dbi) == FALSE)
+	{
+		g_warning ("symbol_db_engine_iterator_new (): cannot set iter to first row");
+	}
+
 	/* set the data_iter on the base class */
 	symbol_db_engine_iterator_node_set_data (SYMBOL_DB_ENGINE_ITERATOR_NODE (dbi),
 											 priv->data_iter);
-	
+
 	symbol_db_engine_iterator_node_set_conversion_hash (SYMBOL_DB_ENGINE_ITERATOR_NODE (dbi),
 														sym_type_conversion_hash);
 	
-	
-	ianjuta_iterable_first (IANJUTA_ITERABLE (dbi), NULL);
+	symbol_db_engine_iterator_node_set_prj_directory (SYMBOL_DB_ENGINE_ITERATOR_NODE (dbi),
+													  prj_directory);
 	return dbi;
 }
 
@@ -126,10 +129,9 @@ symbol_db_engine_iterator_first (SymbolDBEngineIterator *dbi)
 	g_return_val_if_fail (dbi != NULL, FALSE);
 	priv = dbi->priv;
 	
-	return gda_data_model_iter_set_at_row (priv->data_iter, 0);
+	return gda_data_model_iter_move_to_row (priv->data_iter, 0);
 }
 
-
 gboolean
 symbol_db_engine_iterator_move_next (SymbolDBEngineIterator *dbi)
 {
@@ -183,7 +185,7 @@ symbol_db_engine_iterator_last (SymbolDBEngineIterator *dbi)
 	g_return_val_if_fail (dbi != NULL, FALSE);
 	priv = dbi->priv;
 	
-	return gda_data_model_iter_set_at_row (priv->data_iter, 
+	return gda_data_model_iter_move_to_row (priv->data_iter, 
 					symbol_db_engine_iterator_get_n_items (dbi));
 }
 
@@ -195,7 +197,7 @@ symbol_db_engine_iterator_set_position (SymbolDBEngineIterator *dbi, gint pos)
 	g_return_val_if_fail (dbi != NULL, FALSE);
 	priv = dbi->priv;
 	
-	return gda_data_model_iter_set_at_row (priv->data_iter, pos);
+	return gda_data_model_iter_move_to_row (priv->data_iter, pos);
 }
 
 gint
@@ -242,9 +244,6 @@ isymbol_iter_first (IAnjutaIterable *iterable, GError **err)
 
 	if (symbol_db_engine_iterator_first (dbi) == FALSE) 
 	{
-		symbol_db_engine_iterator_node_set_data (SYMBOL_DB_ENGINE_ITERATOR_NODE (iterable),
-										 NULL);
-		
 		return FALSE;
 	}
 	symbol_db_engine_iterator_node_set_data (SYMBOL_DB_ENGINE_ITERATOR_NODE (iterable),
@@ -263,9 +262,6 @@ isymbol_iter_next (IAnjutaIterable *iterable, GError **err)
 
 	if (symbol_db_engine_iterator_move_next (dbi) == FALSE)
 	{
-		symbol_db_engine_iterator_node_set_data (SYMBOL_DB_ENGINE_ITERATOR_NODE (iterable),
-										 NULL);
-		
 		return FALSE;
 	}
 	symbol_db_engine_iterator_node_set_data (SYMBOL_DB_ENGINE_ITERATOR_NODE (iterable),
@@ -285,9 +281,6 @@ isymbol_iter_previous (IAnjutaIterable *iterable, GError **err)
 
 	if (symbol_db_engine_iterator_move_prev (dbi) == FALSE)
 	{
-		symbol_db_engine_iterator_node_set_data (SYMBOL_DB_ENGINE_ITERATOR_NODE (iterable),
-										 NULL);
-		
 		return FALSE;
 	}
 	symbol_db_engine_iterator_node_set_data (SYMBOL_DB_ENGINE_ITERATOR_NODE (iterable),
@@ -307,9 +300,6 @@ isymbol_iter_last (IAnjutaIterable *iterable, GError **err)
 
 	if (symbol_db_engine_iterator_last (dbi) == FALSE)
 	{
-		symbol_db_engine_iterator_node_set_data (SYMBOL_DB_ENGINE_ITERATOR_NODE (iterable),
-										 NULL);
-		
 		return FALSE;
 	}
 	symbol_db_engine_iterator_node_set_data (SYMBOL_DB_ENGINE_ITERATOR_NODE (iterable),
@@ -343,9 +333,6 @@ isymbol_iter_set_position (IAnjutaIterable *iterable,
 
 	if (symbol_db_engine_iterator_set_position (dbi, position) == FALSE)
 	{
-		symbol_db_engine_iterator_node_set_data (SYMBOL_DB_ENGINE_ITERATOR_NODE (iterable),
-										 NULL);
-		
 		return FALSE;
 	}
 	symbol_db_engine_iterator_node_set_data (SYMBOL_DB_ENGINE_ITERATOR_NODE (iterable),
@@ -381,14 +368,14 @@ isymbol_iter_get_length (IAnjutaIterable *iterable, GError **err)
 static IAnjutaIterable *
 isymbol_iter_clone (IAnjutaIterable *iter, GError **e)
 {
-	DEBUG_PRINT ("isymbol_iter_clone  () UNIMPLEMENTED");
+	DEBUG_PRINT ("%s", "isymbol_iter_clone  () UNIMPLEMENTED");
 	return NULL;
 }
 
 static void
 isymbol_iter_assign (IAnjutaIterable *iter, IAnjutaIterable *src_iter, GError **e)
 {
-	DEBUG_PRINT ("isymbol_iter_assign () UNIMPLEMENTED");
+	DEBUG_PRINT ("%s", "isymbol_iter_assign () UNIMPLEMENTED");
 }
 
 
