@@ -64,17 +64,6 @@ symbol_db_gtree_compare_func (gconstpointer a, gconstpointer b, gpointer user_da
 	return GPOINTER_TO_INT(a) - GPOINTER_TO_INT(b);
 }
 
-gboolean
-symbol_db_engine_is_locked (SymbolDBEngine * dbe)
-{
-	SymbolDBEnginePriv *priv;
-
-	g_return_val_if_fail (dbe != NULL, FALSE);
-	
-	priv = dbe->priv;
-	return priv->scanning_status;
-}
-
 gchar*
 symbol_db_engine_get_full_local_path (SymbolDBEngine *dbe, const gchar* file)
 {
@@ -235,7 +224,7 @@ sdb_util_load_symbol_pixbufs ()
 	CREATE_SYM_ICON ("protectedmember",   "element-property-16.png");
 	CREATE_SYM_ICON ("protectedmethod",   "element-method-16.png");
 	CREATE_SYM_ICON ("protectedproperty", "element-property-16.png");
-	CREATE_SYM_ICON ("publicprototype",   "element-interface-16.png");
+	CREATE_SYM_ICON ("protectedprototype","element-interface-16.png");
 	
 	CREATE_SYM_ICON ("publicclass",    	  "element-class-16.png");	
 	CREATE_SYM_ICON ("publicenum",    	  "element-enumeration-16.png");	
