@@ -48,7 +48,7 @@ on_anjuta_delete_event (AnjutaApp *app, GdkEvent *event, gpointer data)
 	AnjutaSavePrompt *save_prompt;
 	gchar *remembered_plugins;
 	
-	DEBUG_PRINT ("AnjutaApp delete event");
+	DEBUG_PRINT ("%s", "AnjutaApp delete event");
 	
 	plugin_manager = anjuta_shell_get_plugin_manager (ANJUTA_SHELL (app), NULL);
 	profile_manager = anjuta_shell_get_profile_manager (ANJUTA_SHELL (app), NULL);
@@ -109,7 +109,7 @@ on_anjuta_delete_event (AnjutaApp *app, GdkEvent *event, gpointer data)
 static void
 on_anjuta_destroy (GtkWidget * w, gpointer data)
 {
-	DEBUG_PRINT ("AnjutaApp destroy event");
+	DEBUG_PRINT ("%s", "AnjutaApp destroy event");
 	
 	gtk_widget_hide (w);
 	gtk_main_quit ();
@@ -125,7 +125,7 @@ on_anjuta_session_save_yourself (GnomeClient * client, gint phase,
 	gchar *argv[] = { "rm",	"-rf", NULL};
 	const gchar *prefix;
 	
-	DEBUG_PRINT ("Going to save session...");
+	DEBUG_PRINT ("%s", "Going to save session...");
 
 	prefix = gnome_client_get_config_prefix (client);
 	argv[2] = gnome_config_get_real_path (prefix);
@@ -138,7 +138,7 @@ on_anjuta_session_save_yourself (GnomeClient * client, gint phase,
 	
 	/*
 	 * We want to be somewhere at last to start, otherwise bonobo-activation
-	 * and gnome-vfs gets screwed up at start up
+	 * gets screwed up at start up
 	 */
 	gnome_client_set_priority (client, 80);
 	
@@ -167,7 +167,7 @@ on_profile_scoped (AnjutaProfileManager *profile_manager,
 	if (strcmp (anjuta_profile_get_name (profile), USER_PROFILE_NAME) != 0)
 		return;
 	
-	DEBUG_PRINT ("User profile loaded; Restoring user session");
+	DEBUG_PRINT ("%s", "User profile loaded; Restoring user session");
 	
 	/* If profile scoped to "user", restore user session */
 	if (system_restore_session)
@@ -210,7 +210,7 @@ on_profile_descoped (AnjutaProfileManager *profile_manager,
 	if (strcmp (anjuta_profile_get_name (profile), USER_PROFILE_NAME) != 0)
 		return;
 	
-	DEBUG_PRINT ("User profile descoped; Saving user session");
+	DEBUG_PRINT ("%s", "User profile descoped; Saving user session");
 	
 	/* If profile descoped from is "user", save user session */
 	session_dir = USER_SESSION_PATH_NEW;
@@ -227,48 +227,34 @@ static gchar*
 extract_project_from_session (const gchar* session_dir)
 {
 	AnjutaSession *session;
-	GList *node, *files, *new_files = NULL;
+	GList *node, *files;
 	gchar *project_uri = NULL;
 	
 	session = anjuta_session_new (session_dir);
 	
 	files = anjuta_session_get_string_list (session, "File Loader", "Files");
-	if (!files)
-		return NULL;
+	g_object_unref (session);
 	
-	/* Open project files first and then regular files */
+	/* Find project file */
 	node = files;
-	while (node)
+	for (node = files; node != NULL; node = g_list_next (node))
 	{
 		gchar *uri = node->data;
 		if (uri)
 		{
-			gchar *mime_type;
-			mime_type = anjuta_util_get_uri_mime_type (uri);
-			if (mime_type && strcmp (mime_type, "application/x-anjuta") == 0)
+			if (anjuta_util_is_project_file (uri))
 			{
 				g_free (project_uri);
 				project_uri = uri;
 			}
 			else
 			{
-				new_files = g_list_prepend (new_files, uri);
+				g_free (uri);
 			}
-			g_free (mime_type);
 		}
-		node = g_list_next (node);
 	}
-	/* anjuta_session_set_string_list (session, "File Loader", "Files", new_files);
-	anjuta_session_sync (session); */
-	g_object_unref (session);
+	g_list_free (files);
 	
-	if (new_files)
-	{
-		g_list_foreach (new_files, (GFunc)g_free, NULL);
-		g_list_free (new_files);
-	}
-	if (files)
-		g_list_free (files);
 	return project_uri;
 }
 
@@ -286,7 +272,7 @@ anjuta_new (gchar *prog_name, GList *prog_args, gboolean no_splash,
 	GnomeClient *client;
 	GnomeClientFlags flags;
 	AnjutaProfile *profile;
-	gchar *session_profile;
+	GFile *session_profile;
 	gchar *remembered_plugins;
 	gchar *project_file = NULL;
 	gchar *profile_name = NULL;
@@ -325,7 +311,8 @@ anjuta_new (gchar *prog_name, GList *prog_args, gboolean no_splash,
 	
 	/* Prepare profile */
 	profile = anjuta_profile_new (USER_PROFILE_NAME, plugin_manager);
-	anjuta_profile_add_plugins_from_xml (profile, DEFAULT_PROFILE,
+	session_profile = g_file_new_for_uri (DEFAULT_PROFILE);
+	anjuta_profile_add_plugins_from_xml (profile, session_profile,
 										 TRUE, &error);
 	if (error)
 	{
@@ -333,11 +320,12 @@ anjuta_new (gchar *prog_name, GList *prog_args, gboolean no_splash,
 		g_error_free (error);
 		error = NULL;
 	}
+	g_object_unref (session_profile);
 	
 	/* Load user session profile */
 	profile_name = g_path_get_basename (DEFAULT_PROFILE);
-	session_profile = anjuta_util_get_user_cache_file_path (profile_name, NULL);
-	if (g_file_test (session_profile, G_FILE_TEST_EXISTS))
+	session_profile = anjuta_util_get_user_cache_file (profile_name, NULL);
+	if (g_file_query_exists (session_profile, NULL))
 	{
 		anjuta_profile_add_plugins_from_xml (profile, session_profile,
 											 FALSE, &error);
@@ -348,8 +336,8 @@ anjuta_new (gchar *prog_name, GList *prog_args, gboolean no_splash,
 			error = NULL;
 		}
 	}
-	anjuta_profile_set_sync_uri (profile, session_profile); 
-	g_free (session_profile);
+	anjuta_profile_set_sync_file (profile, session_profile); 
+	g_object_unref (session_profile);
 	g_free (profile_name);
 	
 	/* Load profile */
@@ -398,32 +386,30 @@ anjuta_new (gchar *prog_name, GList *prog_args, gboolean no_splash,
 									   geometry);
 		
 		/* Identify non-project files and set them for loading in session */
-		node = prog_args;
-		while (node)
+		for (node = prog_args; node != NULL; node = g_list_next (node))
 		{
-			const gchar *ext;
-			const gchar *filename = node->data;
-			
-			ext = strrchr (filename, '.');
-			
-			if (!ext ||
-				(strcmp (ext, ".anjuta") != 0 &&
-				 strcmp (ext, ".prj") != 0))
-			{
-				files_load = g_list_prepend (files_load, node->data);
-			}
-			else
+			gchar *filename = node->data;
+			if (anjuta_util_is_project_file (filename))
 			{
 				/* Pick up the first project file for loading later */
 				g_free (project_file);
 				project_file = g_strdup (filename);
 			}
-			node = g_list_next (node);
+			else
+			{
+				GFile *file = g_file_new_for_path (filename);
+				gchar *uri;
+
+				uri = g_file_get_uri (file);
+				g_object_unref (file);
+				files_load = g_list_prepend (files_load, uri);
+			}
 		}
 		if (files_load)
 		{
 			anjuta_session_set_string_list (session, "File Loader", "Files",
 											files_load);
+			g_list_foreach (files_load, (GFunc)g_free, NULL);
 			g_list_free (files_load);
 		}
 		anjuta_session_sync (session);
@@ -473,7 +459,7 @@ anjuta_new (gchar *prog_name, GList *prog_args, gboolean no_splash,
 	/* Load project file */
 	if (project_file)
 	{
-		GFile* file = g_file_new_for_uri (project_file);
+		GFile* file = g_file_new_for_commandline_arg (project_file);
 		IAnjutaFileLoader *loader;
 		loader = anjuta_shell_get_interface (ANJUTA_SHELL (app),
 											 IAnjutaFileLoader, NULL);
